==> hs-cmdargs-0.7.tbz: lib/ghc-7.0.3/cabal/cmdargs-0.7/register.sh <==
#!/bin/sh
echo 'name: cmdargs
version: 0.7
id: cmdargs-0.7-65e982dcf91eef0193860c81733d1a46

license: BSD3
copyright: Neil Mitchell 2009-2011
maintainer: Neil Mitchell <ndmitchell@gmail.com>
stability: Beta
homepage: http://community.haskell.org/~ndm/cmdargs/
package-url:
description: This library provides an easy way to define command line parsers. Most users
             will want to use the "System.Console.CmdArgs.Implicit" module, whose
             documentation contains an example.
             .
             * "System.Console.CmdArgs.Explicit" provides a way to write command line
             parsers for both single mode programs (most programs) and multiple
             mode programs (e.g. darcs or cabal). Parsers are defined by constructing
             a data structure.
             .
             * "System.Console.CmdArgs.Implicit" provides a way to concisely define
             command line parsers, up to three times shorter than getopt. These parsers
             are translated into the Explicit data type.
             .
             * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
             with existing getopt parsers, mapping to the Explicit data type.
             .
             For a general reference on what command line flags are commonly used,
             see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules: System.Console.CmdArgs
                 System.Console.CmdArgs.Annotate System.Console.CmdArgs.Default
                 System.Console.CmdArgs.Explicit System.Console.CmdArgs.GetOpt
                 System.Console.CmdArgs.Implicit System.Console.CmdArgs.Text
                 System.Console.CmdArgs.Verbosity
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/cmdargs-0.7
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/cmdargs-0.7
              /usr/local/lib
hs-libraries: HScmdargs-0.7
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/cmdargs-0.7/html/cmdargs.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/cmdargs-0.7/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-cmdargs-0.9.2.tbz: lib/ghc-7.0.4/cabal/cmdargs-0.9.2/register.sh <==
#!/bin/sh
echo 'name: cmdargs
version: 0.9.2
id: cmdargs-0.9.2-be9cffcadfbf9327507f67755e016aca

license: BSD3
copyright: Neil Mitchell 2009-2011
maintainer: Neil Mitchell <ndmitchell@gmail.com>
stability: Beta
homepage: http://community.haskell.org/~ndm/cmdargs/
package-url:
description: This library provides an easy way to define command line parsers. Most users
             will want to use the "System.Console.CmdArgs.Implicit" module, whose
             documentation contains an example.
             .
             * "System.Console.CmdArgs.Explicit" provides a way to write command line
             parsers for both single mode programs (most programs) and multiple
             mode programs (e.g. darcs or cabal). Parsers are defined by constructing
             a data structure.
             .
             * "System.Console.CmdArgs.Implicit" provides a way to concisely define
             command line parsers, up to three times shorter than getopt. These parsers
             are translated into the Explicit data type.
             .
             * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
             with existing getopt parsers, mapping to the Explicit data type.
             .
             For a general reference on what command line flags are commonly used,
             see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules: System.Console.CmdArgs.Quote
                 System.Console.CmdArgs System.Console.CmdArgs.Annotate
                 System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
                 System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Implicit
                 System.Console.CmdArgs.Text System.Console.CmdArgs.Helper
                 System.Console.CmdArgs.Verbosity
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/cmdargs-0.9.2
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/cmdargs-0.9.2
              /usr/local/lib
hs-libraries: HScmdargs-0.9.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         process-1.0.1.5-4cab1bf0666275ac101dd48c7565b64c
         template-haskell-2.5.0.0-9ca898a62e2e436d580f8a1457817485
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/cmdargs-0.9.2/html/cmdargs.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/cmdargs-0.9.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
